@@ -4,6 +4,7 @@
 对文件名的处理可选择三种模式: replace(替换字符), head(在开头添加字符), tail(在末尾添加字符)
 
 https://github.com/ahui2016/ffe/raw/main/recipes/rename-part.py
+# ffe >= v0.1.0
 """
 
 # 每个插件都应如上所示在文件开头写简单介绍，以便 "ffe install --peek" 功能窥视插件概要。
@@ -14,6 +15,7 @@ from enum import Enum, auto
 from ffe.model import (
     Recipe,
     ErrMsg,
+    Result,
     must_exist,
     filter_files,
     get_bool,
@@ -49,12 +51,13 @@ new = ""             # 新内容
 method = "replace"   # 有三种方法可选: replace / head / tail
 auto = true          # 根据 old 自动选择文件，需要在 names 里指定一个文件夹
 use_glob = false     # 此项设为 true 时, names 应该使用通配符，如 '*.jpg'
-names = []           # 只有当多个任务组合时才使用此项代替命令行输入
+use_pipe = true      # 是否接受上一个任务的结果
 
 # 本插件的主要用法有两种：
 # 1. 自动根据 old 选择文件，并且把 old 更改为 new, 如果 new 是空字符串则相当于删除 old。
 # 2. method 设为 head 或 tail 时分别表示在文件名的开头或末尾添加 new 的内容。
 # 由于本插件比较复杂，不熟悉时建议多用 'ffe run -dry' 模式预估运行结果，确认无误再真正执行。
+# ffe >= v0.1.0
 """
 
     @property  # 必须设为 @property
@@ -65,6 +68,7 @@ names = []           # 只有当多个任务组合时才使用此项代替命令
             method=EditMethod.Replace.name,
             auto=True,
             use_glob=False,
+            use_pipe=False,
         )
 
     def validate(self, names: list[str], options: dict) -> ErrMsg:
@@ -102,11 +106,6 @@ names = []           # 只有当多个任务组合时才使用此项代替命令
             print("set auto to False because the method is not REPLACE")
             self.auto = False
 
-        # 优先采用 options 里的 names, 方便多个任务组合。
-        options_names = options.get("names", [])
-        if options_names:
-            names = options_names
-
         # 优先采用 auto 模式，其次采用 use_glob 模式，当 auto 与 use_glob 都被设为 False 时
         # 才进入逐一指定具体文件的模式。
         if self.auto:
@@ -137,7 +136,7 @@ names = []           # 只有当多个任务组合时才使用此项代替命令
         self.names = filter_files(self.names)
         return must_exist(self.names)
 
-    def dry_run(self, really_run: bool = False) -> ErrMsg:
+    def dry_run(self, really_run: bool = False) -> Result:
         assert self.is_validated, "在执行 dry_run 之前必须先执行 validate"
 
         print(f"method: {self.method.name}\n")
@@ -154,16 +153,16 @@ names = []           # 只有当多个任务组合时才使用此项代替命令
             case EditMethod.Tail:
                 self.names_add_tail(really_run)
 
-        return ""
+        return list(new_filenames), ""
 
-    def exec(self) -> ErrMsg:
+    def exec(self) -> Result:
         assert self.is_validated, "在执行 exec 之前必须先执行 validate"
         return self.dry_run(really_run=True)
 
     def names_replace(self, really_run: bool) -> None:
         for old_path in self.names:
-            old_path = smart_resolve(old_path)
-            new_name = old_path.name.replace(self.old, self.new)
+            # old_path = smart_resolve(old_path)
+            new_name = old_path.resolve().name.replace(self.old, self.new)
             new_path = old_path.with_name(new_name)
             check_print_run(old_path, new_path, really_run)
 
